searchNodes=[{"doc":"","ref":"mustache.html","title":"mustache","type":"module"},{"doc":"","ref":"mustache.html#compile/1","title":"mustache.compile/1","type":"function"},{"doc":"","ref":"mustache.html#compile/2","title":"mustache.compile/2","type":"function"},{"doc":"","ref":"mustache.html#escape/1","title":"mustache.escape/1","type":"function"},{"doc":"","ref":"mustache.html#get/2","title":"mustache.get/2","type":"function"},{"doc":"","ref":"mustache.html#get/3","title":"mustache.get/3","type":"function"},{"doc":"","ref":"mustache.html#render/1","title":"mustache.render/1","type":"function"},{"doc":"","ref":"mustache.html#render/2","title":"mustache.render/2","type":"function"},{"doc":"","ref":"mustache.html#render/3","title":"mustache.render/3","type":"function"},{"doc":"","ref":"mustache.html#start/1","title":"mustache.start/1","type":"function"},{"doc":"","ref":"mustache_ctx.html","title":"mustache_ctx","type":"module"},{"doc":"","ref":"mustache_ctx.html#get/2","title":"mustache_ctx.get/2","type":"function"},{"doc":"","ref":"mustache_ctx.html#merge/2","title":"mustache_ctx.merge/2","type":"function"},{"doc":"","ref":"mustache_ctx.html#module/1","title":"mustache_ctx.module/1","type":"function"},{"doc":"","ref":"mustache_ctx.html#module/2","title":"mustache_ctx.module/2","type":"function"},{"doc":"","ref":"mustache_ctx.html#new/0","title":"mustache_ctx.new/0","type":"function"},{"doc":"","ref":"mustache_ctx.html#new/1","title":"mustache_ctx.new/1","type":"function"},{"doc":"","ref":"mustache_ctx.html#to_list/1","title":"mustache_ctx.to_list/1","type":"function"},{"doc":"This is Mustache for Erlang, an Erlang port of Mustache for Ruby . Mustache is a framework-agnostic templating system that enforces separation of view logic from the template file. Indeed, it is not even possible to embed logic in the template. This allows templates to be reused across language boundaries and for other language independent uses. This project uses Semantic Versioning for release numbering. Working with Mustache means dealing with templates, views, and contexts. Templates contain HTML (or some other format) and Mustache tags that specify what data to pull in. A template can be either a string or a file (usually ending in .mustache). Views are Erlang modules that can define functions that are called and provide the data for the template tags. A context is an Erlang dict that contains the current context from which tags can pull data. A few examples will clarify how these items interact. NOTE : This is alpha software. Do not use it in production without extensive testing. The API may change at any time. It still lacks some of the features of Mustache for Ruby and the performance (even with compiled templates) is not yet where I'd like it to be.","ref":"readme.html","title":"Overview","type":"extras"},{"doc":"To compile the code, navigate to the mustache.erl project root and issue: make compile","ref":"readme.html#installation","title":"Overview - Installation","type":"extras"},{"doc":"To ease benchmarking of the code we've created the following steps: make shell 1 &gt; bench : run ( ) . This should produce something like: Total time: 2.01s Mean render time: 4.02ms ok","ref":"readme.html#benchmark","title":"Overview - Benchmark","type":"extras"},{"doc":"The simplest example involves using a string template and a context from the REPL. 1 &gt; Ctx = dict : from_list ( [ { planet , &quot;World!&quot; } ] ) . { dict , 1 , 16 , 16 , 8 , 80 , 48 , . . . } 2 &gt; mustache : render ( &quot;Hello {{planet}}&quot; , Ctx ) . &quot;Hello World!&quot; In line 1 we created a context that contains a value bound to the planet tag. In line 2 we rendered a string template by passing in the template and the context.","ref":"readme.html#the-simplest-example","title":"Overview - The Simplest Example","type":"extras"},{"doc":"A more complex example consists of two files: the view and the template. The view (logic) file is an Erlang module (simple.erl): - module ( simple ) . - export ( [ name / 0 ] ) . - export ( [ value / 0 ] ) . - export ( [ taxed_value / 0 ] ) . - export ( [ in_ca / 0 ] ) . name ( ) -&gt; &quot;Tom&quot; . value ( ) -&gt; 10000 . taxed_value ( ) -&gt; value ( ) - ( value ( ) * 0.4 ) . in_ca ( ) -&gt; true . In the view we define functions that will be called by the template. The names of the functions correspond to the tag names that will be used in the template. Some functions reference others, some return values, and some return only booleans. The template file (simple.mustache) looks like so: Hello {{name}} You have just won ${{value}}! {{#in_ca}} Well, ${{ taxed_value }}, after taxes. {{/in_ca}} Notice that the template references the functions in the view module. The return values from the view dictate how the template will be rendered. To get the HTML output, make sure the simple.beam bytecode file is in your code path and call the following function: mustache : render ( simple ) This tells Mustache to use the simple view and to look for a template named simple.mustache in the same directory as the simple.beam bytecode file. If all goes well, it returns the rendered HTML: Hello Tom You have just won $10000! Well, $6000.00, after taxes.","ref":"readme.html#two-file-example","title":"Overview - Two-File Example","type":"extras"},{"doc":"In order to boost performance for templates that will be called many times in the lifetime of a runtime, Mustache allows you to compile a template and then provide that to the render function (instead of having to implicitly recompile the template on each call). 1 &gt; TFun = mustache : compile ( simple ) . 2 &gt; mustache : render ( simple , TFun ) . Now, each call to render will use the compiled template (TFun) instead of compiling the template on its own.","ref":"readme.html#compiled-templates-for-speed","title":"Overview - Compiled Templates (for speed)","type":"extras"},{"doc":"You will often want to provide additional data to your template and view. You can do this by passing in an initial context to the render function. During rendering, tag lookups always hit the context first before looking for a view function. In this way, the context can be used to override view functions. Using the same template and view as above, we can replace the name tag with different data by constructing a context and passing it to render : 1 &gt; Ctx = dict : from_list ( [ { name , &quot;Chris&quot; } ] ) . 2 &gt; TFun = mustache : compile ( simple ) . 3 &gt; mustache : render ( simple , TFun , Ctx ) . This will produce the following output: Hello Chris You have just won $10000! Well, $6000.00, after taxes. The context is also accessible from view functions, making it easy to pass in initialization data. Consider a case where we want to pass in a user ID: Ctx = dict : from_list ( [ { id , 42 } ] ) View functions can get access to the context by accepting a single argument: name ( Ctx ) -&gt; . . . Now when this function is called, it will be handed the context. In order to fetch data from the context, use mustache:get/2 : name ( Ctx ) -&gt; Id = mustache : get ( id , Ctx ) , . . . If the requested key does not exist in the context, the empty list [] will be returned.","ref":"readme.html#the-power-of-context","title":"Overview - The Power of Context","type":"extras"},{"doc":"Tags are indicated by the double mustaches. {{name}} is a tag. Let's talk about the different types of tags. Variables The most basic tag is the variable. A {{name}} tag in a basic template will try to call the name function on your view. By default a variable &quot;miss&quot; returns an empty string. All variables are HTML escaped by default. If you want to return unescaped HTML, use the triple mustache: {{{name}}} . Boolean Sections A section begins with a pound and ends with a slash. That is, {{#person}} begins a &quot;person&quot; section while {{/person}} ends it. If the person method exists and calling it returns false , the HTML between the pound and slash will not be displayed. If the person method exists and calling it returns true , the HTML between the pound and slash will be rendered and displayed. List Sections List sections are syntactically identical to boolean sections in that they begin with a pound and end with a slash. The difference, however, is in the view: if the function called returns a list, the section is repeated as the list is iterated over. Each item in the enumerable is expected to be a dict that will then become the context of the corresponding iteration. In this way we can construct loops. For example, imagine this template: {{#repo}} &lt;b&gt;{{name}}&lt;/b&gt; {{/repo}} And this view code: repo ( ) -&gt; [ dict : from_list ( [ { name , Name } ] ) || Name &lt;- [ &quot;Tom&quot; , &quot;Chris&quot; , &quot;PJ&quot; ] ] . When rendered, our view will contain a list of each of the names in the source list. Comments Comments begin with a bang and are ignored. The following template: &lt;h1&gt;Today{{! ignore me }}.&lt;/h1&gt; Will render as follows: &lt;h1&gt;Today.&lt;/h1&gt;","ref":"readme.html#tag-types","title":"Overview - Tag Types","type":"extras"},{"doc":"All notable changes to this project will be documented in this file. The format is based on Keep a Changelog and this project adheres to Semantic Versioning .","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"Added rebar3_hank [Paulo Oliveira] rebar3_ex_doc + make ex_doc-dry [Paulo Oliveira] Changed CI container approach to setup-beam with cache [Paulo Oliveira] edoc -based doc. to ex_doc -based doc. [Paulo Oliveira]","ref":"changelog.html#1-0-1-2022-04-19","title":"Changelog - [1.0.1] - 2022-04-19","type":"extras"},{"doc":"Added elvis -based Erlang style analysis [Paulo Oliveira] a fresher feel to Makefile [Paulo Oliveira] a fresher feel to rebar.config [Paulo Oliveira] Changed CI from Travis to GitHub Actions [Paulo Oliveira]","ref":"changelog.html#1-0-0-2021-03-04","title":"Changelog - [1.0.0] - 2021-03-04","type":"extras"},{"doc":"The MIT License Copyright (c) 2009 Tom Preston-Werner &lt;tom@mojombo.com&gt; Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the &quot;Software&quot;), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions: The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software. THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html","title":"License","type":"extras"}]